package ru.myitschool.work.api.data;

import androidx.annotation.NonNull;

import java.util.List;
import java.util.function.Consumer;

import ru.myitschool.work.api.data.dto.employee.EmployeeCreateDTO;
import ru.myitschool.work.api.data.network.RetrofitFactory;
import ru.myitschool.work.api.data.source.SignApi;
import ru.myitschool.work.api.data.utils.CallToConsumer;
import ru.myitschool.work.api.domain.SignRepository;
import ru.myitschool.work.api.domain.entity.Status;
import ru.myitschool.work.api.domain.entity.employee.EmpolyeeEntity;

public class SignRepositoryImpl implements SignRepository {
    private static SignRepositoryImpl INSTANCE;
    private final SignApi signApi = RetrofitFactory.getInstance().getSignApi();
    private final CredentialsDataSource credentialsDataSource = CredentialsDataSource.getInstance();

    private SignRepositoryImpl() {
    }

    public static synchronized SignRepositoryImpl getInstance() {
        if (INSTANCE == null) INSTANCE = new SignRepositoryImpl();
        return INSTANCE;
    }

    @Override
    public void createEmployee(@NonNull EmployeeCreateDTO employeeCreateDTO, @NonNull Consumer<Status<EmpolyeeEntity>> callback) {
        signApi.register(employeeCreateDTO).enqueue(new CallToConsumer<>(
                callback,
                employeeDTO -> {
                    if (employeeDTO == null) return null;

                    final long id_ = employeeDTO.id;
                    final String name = employeeDTO.name;
                    final String surname = employeeDTO.surname;
                    final String patronymic = employeeDTO.patronymic;
                    final String telephone = employeeDTO.telephone;
                    final String email_= employeeDTO.email;
                    final long officeId = employeeDTO.officeId;
                    final String officeName = employeeDTO.officeName;
                    final String officeUrl= employeeDTO.officeImageUrl;
                    final String possition = employeeDTO.position;
                    final String role = employeeDTO.role;
                    final String profileImageUrl= employeeDTO.profileImageUrl;
                    final boolean visitStatus= employeeDTO.visitStatus;
                    final String startVisit= employeeDTO.startVisitDateTime;
                    final List<Long> visitIdLast30Days = employeeDTO.visitsIdLast30Days;
                    final long totalVisitTimeLast30Days = employeeDTO.totalTimeVisitsLast30Days;
                    final String curentOfficeName = employeeDTO.currentOfficeName;
                    final String createdAt= employeeDTO.createAt;

                    if (name != null && surname != null && telephone != null &&
                            email_ != null && officeName != null && officeUrl != null &&
                            possition != null && role != null && startVisit != null &&
                            visitIdLast30Days != null && curentOfficeName != null &&
                            createdAt != null) {

                        return new EmpolyeeEntity(id_, name, surname, patronymic,
                                telephone, email_, officeId, officeName, officeUrl, possition, role, profileImageUrl,
                                visitStatus, startVisit, visitIdLast30Days, totalVisitTimeLast30Days, curentOfficeName, createdAt);
                    } else return null;
                })
        );
    }

    @Override
    public void login(@NonNull String email, @NonNull String password, @NonNull Consumer<Status<EmpolyeeEntity>> callback) {
        credentialsDataSource.updateLogin(email, password);
        signApi.login().enqueue(new CallToConsumer<>(callback, employeeDTO -> {
            if (employeeDTO == null) return null;

            final long id_ = employeeDTO.id;
            final String name = employeeDTO.name;
            final String surname = employeeDTO.surname;
            final String patronymic = employeeDTO.patronymic;
            final String telephone = employeeDTO.telephone;
            final String email_= employeeDTO.email;
            final long officeId = employeeDTO.officeId;
            final String officeName = employeeDTO.officeName;
            final String officeUrl= employeeDTO.officeImageUrl;
            final String possition = employeeDTO.position;
            final String role = employeeDTO.role;
            final String profileImageUrl= employeeDTO.profileImageUrl;
            final boolean visitStatus= employeeDTO.visitStatus;
            final String startVisit= employeeDTO.startVisitDateTime;
            final List<Long> visitIdLast30Days = employeeDTO.visitsIdLast30Days;
            final long totalVisitTimeLast30Days = employeeDTO.totalTimeVisitsLast30Days;
            final String curentOfficeName = employeeDTO.currentOfficeName;
            final String createdAt= employeeDTO.createAt;

            if (name != null && surname != null && telephone != null &&
                    email_ != null && officeName != null && officeUrl != null &&
                    possition != null && role != null && startVisit != null &&
                    visitIdLast30Days != null && curentOfficeName != null &&
                    createdAt != null) {

                return new EmpolyeeEntity(id_, name, surname, patronymic,
                        telephone, email_, officeId, officeName, officeUrl, possition, role, profileImageUrl,
                        visitStatus, startVisit, visitIdLast30Days, totalVisitTimeLast30Days, curentOfficeName, createdAt);
            } else return null;
        }));
    }

    @Override
    public void logout() {
        credentialsDataSource.logout();
    }
}
