package ru.myitschool.work.api.data;

import androidx.annotation.NonNull;

import com.example.myapplication.api.domain.entity.visit.VisitEntity;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.function.Consumer;

import ru.myitschool.work.api.data.dto.VisitDTO;
import ru.myitschool.work.api.data.network.RetrofitFactory;
import ru.myitschool.work.api.data.source.VisitApi;
import ru.myitschool.work.api.data.utils.CallToConsumer;
import ru.myitschool.work.api.domain.VisitRepository;
import ru.myitschool.work.api.domain.entity.Status;
import com.example.myapplication.api.domain.entity.visit.VisitEntity;


public class VisitRepositoryImpl implements VisitRepository {
    private static VisitRepositoryImpl INSTANCE;
    private final VisitApi visitApi = RetrofitFactory.getInstance().getVisitApi();


    public static synchronized VisitRepositoryImpl getInstance() {
        if (INSTANCE == null) INSTANCE = new VisitRepositoryImpl();
        return INSTANCE;
    }

    @Override
    public void getAllVisits(@NonNull Consumer<Status<List<VisitEntity>>> callback) {
        visitApi.getAll().enqueue(new CallToConsumer<>(
                callback,
                visitDTOS -> {
                    if (visitDTOS == null) return null;

                    ArrayList<VisitEntity> result = new ArrayList<>(visitDTOS.size());

                    for (VisitDTO visitDTO : visitDTOS) {
                        if (visitDTO == null) continue;

                        final long id = visitDTO.id;
                        final LocalDateTime startVisit = visitDTO.startVisit;
                        final LocalDateTime endVisit = visitDTO.endVisit;
                        final String totalTime =visitDTO.durationVisit;
                        final boolean isFinished = visitDTO.isFinished;
                        final long startTerminal = visitDTO.startTertminal;
                        final long endTerminal = visitDTO.endTerminal;

                        if (startVisit != null && endVisit != null && totalTime != null && isFinished) {
                            result.add(new VisitEntity(id, startVisit, endVisit, totalTime, isFinished,startTerminal,endTerminal));
                        }
                    }
                    return result;
                }
        ));
    }

    @Override
    public void getAllByVisitId(long id, @NonNull Consumer<Status<List<VisitEntity>>> callback) {

    }

//    @Override
//    public void getAllByVisitId(long id, @NonNull Consumer<Status<List<VisitEntity>>> callback) {
//        visitApi.getVisitById(id).enqueue(new CallToConsumer<>(
//                callback,
//                visitDTOS -> {
//                    if (visitDTOS == null) return null;
//
//                    ArrayList<VisitEntity> result = new ArrayList<>(visitDTOS.size());
//
//                    for (VisitDTO visitDTO : visitDTOS) {
//                        if (visitDTO == null) continue;
//
//                        final long Id = visitDTO.id;
//                        final LocalDateTime startVisit = visitDTO.startVisit;
//                        final LocalDateTime endVisit = visitDTO.endVisit;
//                        final String totalTime =visitDTO.durationVisit;
//                        final boolean isFinished = visitDTO.isFinished;
//                        final long startTerminal = visitDTO.startTertminal;
//                        final long endTerminal = visitDTO.endTerminal;
//
//                        if (startVisit != null && endVisit != null && totalTime != null && isFinished) {
//                            result.add(new VisitEntity(Id, startVisit, endVisit, totalTime, isFinished,startTerminal,endTerminal));
//                        }
//                    }
//                    return result;
//                }
//        ));
//    }

    /* это если время останется. Шаблон есть фуловый, только на сервере надо
    @Override
    public void createVisit(@NonNull NotificationDTO notificationDTO, @NonNull Consumer<Status<VisitEntity>> callback) {

    }*/
}
