package ru.myitschool.work.api.data.network;

import com.example.myapplication.core.UrlConstants;

import okhttp3.OkHttpClient;
import okhttp3.Request;
import retrofit2.Retrofit;
import retrofit2.converter.gson.GsonConverterFactory;
import ru.myitschool.work.api.data.CredentialsDataSource;
import ru.myitschool.work.api.data.source.EmployeeApi;
import ru.myitschool.work.api.data.source.OfficeApi;
import ru.myitschool.work.api.data.source.SignApi;
import ru.myitschool.work.api.data.source.VisitApi;

public class RetrofitFactory {
    private static RetrofitFactory INSTANCE;

    private RetrofitFactory() {
    }

    public static synchronized RetrofitFactory getInstance() {
        if (INSTANCE == null) INSTANCE = new RetrofitFactory();
        return INSTANCE;
    }

    private final OkHttpClient.Builder client = new OkHttpClient.Builder()
            .addInterceptor(chain -> {
                String authData = CredentialsDataSource.getInstance().getAuthData();

                if (authData == null) return chain.proceed(chain.request());
                else {
                    Request request = chain.request()
                            .newBuilder()
                            .addHeader("Authorization", authData)
                            .build();
                    return chain.proceed(request);
                }
            });

    public Retrofit retrofit = new Retrofit.Builder()
            .baseUrl(UrlConstants.BASE_URL)
            .client(client.build())
            .addConverterFactory(GsonConverterFactory.create())
            .build();

    public EmployeeApi getEmployeeApi() {
        return retrofit.create(EmployeeApi.class);
    }

    public SignApi getSignApi() {
        return retrofit.create(SignApi.class);
    }

    public OfficeApi getOfficeApi() {
        return retrofit.create(OfficeApi.class);
    }
    public VisitApi getVisitApi(){ return retrofit.create(VisitApi.class);}
}
